]> sjero.net Git - wget/blobdiff - src/url.h
[svn] Handle <base href=...> when converting links.
[wget] / src / url.h
index 3c74a0e244226c1217cd8780aca1a7593f89e608..836cdad1bb2661eb22cb78456b6458a8015efa85 100644 (file)
--- a/src/url.h
+++ b/src/url.h
@@ -25,6 +25,9 @@ Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
 #define DEFAULT_FTP_PORT 21
 #define DEFAULT_HTTPS_PORT 443
 
+/* Note: the ordering here is related to the order of elements in
+   `supported_schemes' in url.c.  */
+
 enum url_scheme {
   SCHEME_HTTP,
 #ifdef HAVE_SSL
@@ -35,47 +38,57 @@ enum url_scheme {
 };
 
 /* Structure containing info on a URL.  */
-struct urlinfo
+struct url
 {
-  char *url;                   /* Unchanged URL */
+  char *url;                   /* Original URL */
   enum url_scheme scheme;      /* URL scheme */
 
   char *host;                  /* Extracted hostname */
-  unsigned short port;
-  char ftp_type;
-  char *path, *dir, *file, *qstring;   
-                                /* Path, dir, file, and query string
-                                  (properly decoded) */
-  char *user, *passwd;         /* Username and password */
-  struct urlinfo *proxy;       /* The exact string to pass to proxy
-                                  server */
-  char *referer;               /* The source from which the request
-                                  URI was obtained */
-  char *local;                 /* The local filename of the URL
-                                  document */
+  int port;                    /* Port number */
+
+  /* URL components (URL-quoted). */
+  char *path;
+  char *params;
+  char *query;
+  char *fragment;
+
+  /* Extracted path info (unquoted). */
+  char *dir;
+  char *file;
+
+  /* Username and password (unquoted). */
+  char *user;
+  char *passwd;
 };
 
 enum convert_options {
   CO_NOCONVERT = 0,            /* don't convert this URL */
   CO_CONVERT_TO_RELATIVE,      /* convert to relative, e.g. to
                                    "../../otherdir/foo.gif" */
-  CO_CONVERT_TO_COMPLETE       /* convert to absolute, e.g. to
+  CO_CONVERT_TO_COMPLETE,      /* convert to absolute, e.g. to
                                   "http://orighost/somedir/bar.jpg". */
+  CO_NULLIFY_BASE              /* change to empty string. */
 };
 
 /* A structure that defines the whereabouts of a URL, i.e. its
    position in an HTML document, etc.  */
 
-typedef struct _urlpos
-{
-  char *url;                   /* linked URL, after it has been
-                                  merged with the base */
-  char *local_name;            /* Local file to which it was saved */
+struct urlpos {
+  struct url *url;             /* the URL of the link, after it has
+                                  been merged with the base */
+  char *local_name;            /* local file to which it was saved
+                                  (used by convert_links) */
+
+  int ignore_when_downloading; /* reserved for special links such as
+                                  <base href="..."> which are used
+                                  when converting links, but ignored
+                                  when downloading.  */
 
   /* Information about the original link: */
   int link_relative_p;         /* was the link relative? */
   int link_complete_p;         /* was the link complete (with the
                                    host name, etc.) */
+  int link_base_p;             /* was the link <base href=...> */
 
   /* Conversion requirements: */
   enum convert_options convert;        /* is conversion required? */
@@ -83,8 +96,8 @@ typedef struct _urlpos
   /* URL's position in the buffer. */
   int pos, size;
 
-  struct _urlpos *next;                /* Next struct in list */
-} urlpos;
+  struct urlpos *next;         /* next list element */
+};
 
 /* downloaded_file() takes a parameter of this type and returns this type. */
 typedef enum
@@ -104,37 +117,39 @@ typedef enum
 
 char *encode_string PARAMS ((const char *));
 
-struct urlinfo *newurl PARAMS ((void));
-void freeurl PARAMS ((struct urlinfo *, int));
-enum url_scheme url_detect_scheme PARAMS ((const char *));
+struct url *url_parse PARAMS ((const char *, int *));
+const char *url_error PARAMS ((int));
+char *url_full_path PARAMS ((const struct url *));
+void url_set_dir PARAMS ((struct url *, const char *));
+void url_set_file PARAMS ((struct url *, const char *));
+void url_free PARAMS ((struct url *));
+
+enum url_scheme url_scheme PARAMS ((const char *));
 int url_skip_scheme PARAMS ((const char *));
 int url_has_scheme PARAMS ((const char *));
+int scheme_default_port PARAMS ((enum url_scheme));
+
 int url_skip_uname PARAMS ((const char *));
 
-uerr_t parseurl PARAMS ((const char *, struct urlinfo *, int));
-char *str_url PARAMS ((const struct urlinfo *, int));
-/* url_equal is not currently used. */
-#if 0
-int url_equal PARAMS ((const char *, const char *));
-#endif /* 0 */
+char *url_string PARAMS ((const struct url *, int));
 
-urlpos *get_urls_file PARAMS ((const char *));
-urlpos *get_urls_html PARAMS ((const char *, const char *, int, int *));
-void free_urlpos PARAMS ((urlpos *));
+struct urlpos *get_urls_file PARAMS ((const char *));
+struct urlpos *get_urls_html PARAMS ((const char *, const char *, int, int *));
+void free_urlpos PARAMS ((struct urlpos *));
 
 char *uri_merge PARAMS ((const char *, const char *));
 
 void rotate_backups PARAMS ((const char *));
 int mkalldirs PARAMS ((const char *));
-char *url_filename PARAMS ((const struct urlinfo *));
-void opt_url PARAMS ((struct urlinfo *));
+char *url_filename PARAMS ((const struct url *));
 
-char *getproxy PARAMS ((uerr_t));
+char *getproxy PARAMS ((enum url_scheme));
 int no_proxy_match PARAMS ((const char *, const char **));
 
-void convert_links PARAMS ((const char *, urlpos *));
-urlpos *add_url PARAMS ((urlpos *, const char *, const char *));
+void convert_links PARAMS ((const char *, struct urlpos *));
 
 downloaded_file_t downloaded_file PARAMS ((downloaded_file_t, const char *));
 
+char *rewrite_shorthand_url PARAMS ((const char *));
+
 #endif /* URL_H */